# equinix-metal
# Introduction
Equinix Metal provides a RESTful HTTP API which can be reached at <https://api.equinix.com/metal/v1>. This document describes the API and how to use it.

The API allows you to programmatically interact with all
of your Equinix Metal resources, including devices, networks, addresses, organizations,
projects, and your user account. Every feature of the Equinix Metal web interface is accessible through the API.

The API docs are generated from the Equinix Metal OpenAPI specification and are officially hosted at <https://metal.equinix.com/developers/api>.

# Common Parameters

The Equinix Metal API uses a few methods to minimize network traffic and improve throughput. These parameters are not used in all API calls, but are used often enough to warrant their own section. Look for these parameters in the documentation for the API calls that support them.

## Pagination

Pagination is used to limit the number of results returned in a single request. The API will return a maximum of 100 results per page. To retrieve additional results, you can use the `page` and `per_page` query parameters.

The `page` parameter is used to specify the page number. The first page is `1`. The `per_page` parameter is used to specify the number of results per page. The maximum number of results differs by resource type.

## Sorting

Where offered, the API allows you to sort results by a specific field. To sort results use the `sort_by` query parameter with the root level field name as the value. The `sort_direction` parameter is used to specify the sort direction, either either `asc` (ascending) or `desc` (descending).

## Filtering

Filtering is used to limit the results returned in a single request. The API supports filtering by certain fields in the response. To filter results, you can use the field as a query parameter.

For example, to filter the IP list to only return public IPv4 addresses, you can filter by the `type` field, as in the following request:

```sh
curl -H 'X-Auth-Token: my_authentication_token' \\
  https://api.equinix.com/metal/v1/projects/id/ips?type=public_ipv4
```

Only IP addresses with the `type` field set to `public_ipv4` will be returned.

## Searching

Searching is used to find matching resources using multiple field comparissons. The API supports searching in resources that define this behavior. Currently the search parameter is only available on devices, ssh_keys, api_keys and memberships endpoints.

To search resources you can use the `search` query parameter.

## Include and Exclude

For resources that contain references to other resources, sucha as a Device that refers to the Project it resides in, the Equinix Metal API will returns `href` values (API links) to the associated resource.

```json
{
  ...
  \"project\": {
    \"href\": \"/metal/v1/projects/f3f131c8-f302-49ef-8c44-9405022dc6dd\"
  }
}
```

If you're going need the project details, you can avoid a second API request.  Specify the contained `href` resources and collections that you'd like to have included in the response using the `include` query parameter.

For example:

```sh
curl -H 'X-Auth-Token: my_authentication_token' \\
  https://api.equinix.com/metal/v1/user?include=projects
```

The `include` parameter is generally accepted in `GET`, `POST`, `PUT`, and `PATCH` requests where `href` resources are presented.

To have multiple resources include, use a comma-separated list (e.g. `?include=emails,projects,memberships`).

```sh
curl -H 'X-Auth-Token: my_authentication_token' \\
  https://api.equinix.com/metal/v1/user?include=emails,projects,memberships
```

You may also include nested associations up to three levels deep using dot notation (`?include=memberships.projects`):

```sh
curl -H 'X-Auth-Token: my_authentication_token' \\
  https://api.equinix.com/metal/v1/user?include=memberships.projects
```

To exclude resources, and optimize response delivery, use the `exclude` query parameter. The `exclude` parameter is generally accepted in `GET`, `POST`, `PUT`, and `PATCH` requests for fields with nested object responses. When excluded, these fields will be replaced with an object that contains only an `href` field.


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- Package version: 0.4.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/equinix-labs/metal-python.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/equinix-labs/metal-python.git`)

Then import the package:
```python
import equinix_metal
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import equinix_metal
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import equinix_metal
from equinix_metal.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.equinix.com/metal/v1
# See configuration.py for a list of all supported configuration parameters.
configuration = equinix_metal.Configuration(
    host = "https://api.equinix.com/metal/v1"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: x_auth_token
configuration.api_key['x_auth_token'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['x_auth_token'] = 'Bearer'


# Enter a context with an instance of the API client
with equinix_metal.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = equinix_metal.AuthenticationApi(api_client)
    auth_token_input = equinix_metal.AuthTokenInput() # AuthTokenInput | API key to create
    include = ['include_example'] # List[str] | Nested attributes to include. Included objects will return their full attributes. Attribute names can be dotted (up to 3 levels) to included deeply nested objects. (optional)

    try:
        # Create an API key
        api_response = api_instance.create_api_key(auth_token_input, include=include)
        print("The response of AuthenticationApi->create_api_key:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AuthenticationApi->create_api_key: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.equinix.com/metal/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AuthenticationApi* | [**create_api_key**](docs/AuthenticationApi.md#create_api_key) | **POST** /user/api-keys | Create an API key
*AuthenticationApi* | [**create_project_api_key**](docs/AuthenticationApi.md#create_project_api_key) | **POST** /projects/{id}/api-keys | Create an API key for a project.
*AuthenticationApi* | [**delete_api_key**](docs/AuthenticationApi.md#delete_api_key) | **DELETE** /api-keys/{id} | Delete the API key
*AuthenticationApi* | [**delete_user_api_key**](docs/AuthenticationApi.md#delete_user_api_key) | **DELETE** /user/api-keys/{id} | Delete the API key
*AuthenticationApi* | [**find_api_keys**](docs/AuthenticationApi.md#find_api_keys) | **GET** /user/api-keys | Retrieve all user API keys
*AuthenticationApi* | [**find_project_api_keys**](docs/AuthenticationApi.md#find_project_api_keys) | **GET** /projects/{id}/api-keys | Retrieve all API keys for the project.
*BGPApi* | [**delete_bgp_session**](docs/BGPApi.md#delete_bgp_session) | **DELETE** /bgp/sessions/{id} | Delete the BGP session
*BGPApi* | [**find_bgp_config_by_project**](docs/BGPApi.md#find_bgp_config_by_project) | **GET** /projects/{id}/bgp-config | Retrieve a bgp config
*BGPApi* | [**find_bgp_session_by_id**](docs/BGPApi.md#find_bgp_session_by_id) | **GET** /bgp/sessions/{id} | Retrieve a BGP session
*BGPApi* | [**find_global_bgp_ranges**](docs/BGPApi.md#find_global_bgp_ranges) | **GET** /projects/{id}/global-bgp-ranges | Retrieve all global bgp ranges
*BGPApi* | [**find_project_bgp_sessions**](docs/BGPApi.md#find_project_bgp_sessions) | **GET** /projects/{id}/bgp/sessions | Retrieve all BGP sessions for project
*BGPApi* | [**request_bgp_config**](docs/BGPApi.md#request_bgp_config) | **POST** /projects/{id}/bgp-configs | Requesting bgp config
*BGPApi* | [**update_bgp_session**](docs/BGPApi.md#update_bgp_session) | **PUT** /bgp/sessions/{id} | Update the BGP session
*BatchesApi* | [**create_device_batch**](docs/BatchesApi.md#create_device_batch) | **POST** /projects/{id}/devices/batch | Create a devices batch
*BatchesApi* | [**delete_batch**](docs/BatchesApi.md#delete_batch) | **DELETE** /batches/{id} | Delete the Batch
*BatchesApi* | [**find_batch_by_id**](docs/BatchesApi.md#find_batch_by_id) | **GET** /batches/{id} | Retrieve a Batch
*BatchesApi* | [**find_batches_by_project**](docs/BatchesApi.md#find_batches_by_project) | **GET** /projects/{id}/batches | Retrieve all batches by project
*CapacityApi* | [**check_capacity_for_facility**](docs/CapacityApi.md#check_capacity_for_facility) | **POST** /capacity | Check capacity
*CapacityApi* | [**check_capacity_for_metro**](docs/CapacityApi.md#check_capacity_for_metro) | **POST** /capacity/metros | Check capacity for a metro
*CapacityApi* | [**find_capacity_for_facility**](docs/CapacityApi.md#find_capacity_for_facility) | **GET** /capacity | View capacity
*CapacityApi* | [**find_capacity_for_metro**](docs/CapacityApi.md#find_capacity_for_metro) | **GET** /capacity/metros | View capacity for metros
*CapacityApi* | [**find_organization_capacity_per_facility**](docs/CapacityApi.md#find_organization_capacity_per_facility) | **GET** /organizations/{id}/capacity | View available hardware plans per Facility for given organization
*CapacityApi* | [**find_organization_capacity_per_metro**](docs/CapacityApi.md#find_organization_capacity_per_metro) | **GET** /organizations/{id}/capacity/metros | View available hardware plans per Metro for given organization
*DevicesApi* | [**create_bgp_session**](docs/DevicesApi.md#create_bgp_session) | **POST** /devices/{id}/bgp/sessions | Create a BGP session
*DevicesApi* | [**create_device**](docs/DevicesApi.md#create_device) | **POST** /projects/{id}/devices | Create a device
*DevicesApi* | [**create_ip_assignment**](docs/DevicesApi.md#create_ip_assignment) | **POST** /devices/{id}/ips | Create an ip assignment
*DevicesApi* | [**delete_device**](docs/DevicesApi.md#delete_device) | **DELETE** /devices/{id} | Delete the device
*DevicesApi* | [**find_bgp_sessions**](docs/DevicesApi.md#find_bgp_sessions) | **GET** /devices/{id}/bgp/sessions | Retrieve all BGP sessions
*DevicesApi* | [**find_device_by_id**](docs/DevicesApi.md#find_device_by_id) | **GET** /devices/{id} | Retrieve a device
*DevicesApi* | [**find_device_customdata**](docs/DevicesApi.md#find_device_customdata) | **GET** /devices/{id}/customdata | Retrieve the custom metadata of an instance
*DevicesApi* | [**find_device_metadata_by_id**](docs/DevicesApi.md#find_device_metadata_by_id) | **GET** /devices/{id}/metadata | Retrieve metadata
*DevicesApi* | [**find_device_userdata_by_id**](docs/DevicesApi.md#find_device_userdata_by_id) | **GET** /devices/{id}/userdata | Retrieve userdata
*DevicesApi* | [**find_instance_bandwidth**](docs/DevicesApi.md#find_instance_bandwidth) | **GET** /devices/{id}/bandwidth | Retrieve an instance bandwidth
*DevicesApi* | [**find_ip_assignment_customdata**](docs/DevicesApi.md#find_ip_assignment_customdata) | **GET** /devices/{instance_id}/ips/{id}/customdata | Retrieve the custom metadata of an IP Assignment
*DevicesApi* | [**find_ip_assignments**](docs/DevicesApi.md#find_ip_assignments) | **GET** /devices/{id}/ips | Retrieve all ip assignments
*DevicesApi* | [**find_organization_devices**](docs/DevicesApi.md#find_organization_devices) | **GET** /organizations/{id}/devices | Retrieve all devices of an organization
*DevicesApi* | [**find_project_devices**](docs/DevicesApi.md#find_project_devices) | **GET** /projects/{id}/devices | Retrieve all devices of a project
*DevicesApi* | [**find_traffic**](docs/DevicesApi.md#find_traffic) | **GET** /devices/{id}/traffic | Retrieve device traffic
*DevicesApi* | [**get_bgp_neighbor_data**](docs/DevicesApi.md#get_bgp_neighbor_data) | **GET** /devices/{id}/bgp/neighbors | Retrieve BGP neighbor data for this device
*DevicesApi* | [**get_device_firmware_sets**](docs/DevicesApi.md#get_device_firmware_sets) | **GET** /devices/{id}/firmware-sets | Get Device&#39;s associated Firmware Set
*DevicesApi* | [**get_device_health_rollup**](docs/DevicesApi.md#get_device_health_rollup) | **GET** /devices/{id}/diagnostics/health/rollup | Get Device&#39;s Health Status
*DevicesApi* | [**perform_action**](docs/DevicesApi.md#perform_action) | **POST** /devices/{id}/actions | Perform an action
*DevicesApi* | [**update_device**](docs/DevicesApi.md#update_device) | **PUT** /devices/{id} | Update the device
*EmailsApi* | [**create_email**](docs/EmailsApi.md#create_email) | **POST** /emails | Create an email
*EmailsApi* | [**delete_email**](docs/EmailsApi.md#delete_email) | **DELETE** /emails/{id} | Delete the email
*EmailsApi* | [**find_email_by_id**](docs/EmailsApi.md#find_email_by_id) | **GET** /emails/{id} | Retrieve an email
*EmailsApi* | [**update_email**](docs/EmailsApi.md#update_email) | **PUT** /emails/{id} | Update the email
*EventsApi* | [**find_device_events**](docs/EventsApi.md#find_device_events) | **GET** /devices/{id}/events | Retrieve device&#39;s events
*EventsApi* | [**find_event_by_id**](docs/EventsApi.md#find_event_by_id) | **GET** /events/{id} | Retrieve an event
*EventsApi* | [**find_events**](docs/EventsApi.md#find_events) | **GET** /events | Retrieve current user&#39;s events
*EventsApi* | [**find_interconnection_events**](docs/EventsApi.md#find_interconnection_events) | **GET** /connections/{connection_id}/events | Retrieve interconnection events
*EventsApi* | [**find_interconnection_port_events**](docs/EventsApi.md#find_interconnection_port_events) | **GET** /connections/{connection_id}/ports/{id}/events | Retrieve interconnection port events
*EventsApi* | [**find_organization_events**](docs/EventsApi.md#find_organization_events) | **GET** /organizations/{id}/events | Retrieve organization&#39;s events
*EventsApi* | [**find_project_events**](docs/EventsApi.md#find_project_events) | **GET** /projects/{id}/events | Retrieve project&#39;s events
*EventsApi* | [**find_virtual_circuit_events**](docs/EventsApi.md#find_virtual_circuit_events) | **GET** /virtual-circuits/{id}/events | Retrieve virtual circuit events
*EventsApi* | [**find_vrf_route_events**](docs/EventsApi.md#find_vrf_route_events) | **GET** /routes/{id}/events | Retrieve VRF route events
*FacilitiesApi* | [**find_facilities**](docs/FacilitiesApi.md#find_facilities) | **GET** /facilities | Retrieve all facilities
*FacilitiesApi* | [**find_facilities_by_organization**](docs/FacilitiesApi.md#find_facilities_by_organization) | **GET** /organizations/{id}/facilities | Retrieve all facilities visible by the organization
*FacilitiesApi* | [**find_facilities_by_project**](docs/FacilitiesApi.md#find_facilities_by_project) | **GET** /projects/{id}/facilities | Retrieve all facilities visible by the project
*FirmwareSetsApi* | [**get_organization_firmware_sets**](docs/FirmwareSetsApi.md#get_organization_firmware_sets) | **GET** /organizations/{id}/firmware-sets | Get Organization&#39;s Firmware Sets
*FirmwareSetsApi* | [**get_project_firmware_sets**](docs/FirmwareSetsApi.md#get_project_firmware_sets) | **GET** /projects/{id}/firmware-sets | Get Project&#39;s Firmware Sets
*HardwareReservationsApi* | [**activate_hardware_reservation**](docs/HardwareReservationsApi.md#activate_hardware_reservation) | **POST** /hardware-reservations/{id}/activate | Activate a spare hardware reservation
*HardwareReservationsApi* | [**find_hardware_reservation_by_id**](docs/HardwareReservationsApi.md#find_hardware_reservation_by_id) | **GET** /hardware-reservations/{id} | Retrieve a hardware reservation
*HardwareReservationsApi* | [**find_project_hardware_reservations**](docs/HardwareReservationsApi.md#find_project_hardware_reservations) | **GET** /projects/{id}/hardware-reservations | Retrieve all hardware reservations for a given project
*HardwareReservationsApi* | [**move_hardware_reservation**](docs/HardwareReservationsApi.md#move_hardware_reservation) | **POST** /hardware-reservations/{id}/move | Move a hardware reservation
*IPAddressesApi* | [**delete_ip_address**](docs/IPAddressesApi.md#delete_ip_address) | **DELETE** /ips/{id} | Unassign an ip address
*IPAddressesApi* | [**find_ip_address_by_id**](docs/IPAddressesApi.md#find_ip_address_by_id) | **GET** /ips/{id} | Retrieve an ip address
*IPAddressesApi* | [**find_ip_address_customdata**](docs/IPAddressesApi.md#find_ip_address_customdata) | **GET** /ips/{id}/customdata | Retrieve the custom metadata of an IP Reservation or IP Assignment
*IPAddressesApi* | [**find_ip_availabilities**](docs/IPAddressesApi.md#find_ip_availabilities) | **GET** /ips/{id}/available | Retrieve all available subnets of a particular reservation
*IPAddressesApi* | [**find_ip_reservations**](docs/IPAddressesApi.md#find_ip_reservations) | **GET** /projects/{id}/ips | Retrieve all ip reservations
*IPAddressesApi* | [**request_ip_reservation**](docs/IPAddressesApi.md#request_ip_reservation) | **POST** /projects/{id}/ips | Requesting IP reservations
*IPAddressesApi* | [**update_ip_address**](docs/IPAddressesApi.md#update_ip_address) | **PATCH** /ips/{id} | Update an ip address
*IncidentsApi* | [**find_incidents**](docs/IncidentsApi.md#find_incidents) | **GET** /incidents | Retrieve the number of incidents
*InterconnectionsApi* | [**create_interconnection_port_virtual_circuit**](docs/InterconnectionsApi.md#create_interconnection_port_virtual_circuit) | **POST** /connections/{connection_id}/ports/{port_id}/virtual-circuits | Create a new Virtual Circuit
*InterconnectionsApi* | [**create_organization_interconnection**](docs/InterconnectionsApi.md#create_organization_interconnection) | **POST** /organizations/{organization_id}/connections | Request a new interconnection for the organization
*InterconnectionsApi* | [**create_project_interconnection**](docs/InterconnectionsApi.md#create_project_interconnection) | **POST** /projects/{project_id}/connections | Request a new interconnection for the project&#39;s organization
*InterconnectionsApi* | [**delete_interconnection**](docs/InterconnectionsApi.md#delete_interconnection) | **DELETE** /connections/{connection_id} | Delete interconnection
*InterconnectionsApi* | [**delete_virtual_circuit**](docs/InterconnectionsApi.md#delete_virtual_circuit) | **DELETE** /virtual-circuits/{id} | Delete a virtual circuit
*InterconnectionsApi* | [**get_interconnection**](docs/InterconnectionsApi.md#get_interconnection) | **GET** /connections/{connection_id} | Get interconnection
*InterconnectionsApi* | [**get_interconnection_port**](docs/InterconnectionsApi.md#get_interconnection_port) | **GET** /connections/{connection_id}/ports/{id} | Get a interconnection port
*InterconnectionsApi* | [**get_virtual_circuit**](docs/InterconnectionsApi.md#get_virtual_circuit) | **GET** /virtual-circuits/{id} | Get a virtual circuit
*InterconnectionsApi* | [**list_interconnection_port_virtual_circuits**](docs/InterconnectionsApi.md#list_interconnection_port_virtual_circuits) | **GET** /connections/{connection_id}/ports/{port_id}/virtual-circuits | List a interconnection port&#39;s virtual circuits
*InterconnectionsApi* | [**list_interconnection_ports**](docs/InterconnectionsApi.md#list_interconnection_ports) | **GET** /connections/{connection_id}/ports | List a interconnection&#39;s ports
*InterconnectionsApi* | [**list_interconnection_virtual_circuits**](docs/InterconnectionsApi.md#list_interconnection_virtual_circuits) | **GET** /connections/{connection_id}/virtual-circuits | List a interconnection&#39;s virtual circuits
*InterconnectionsApi* | [**organization_list_interconnections**](docs/InterconnectionsApi.md#organization_list_interconnections) | **GET** /organizations/{organization_id}/connections | List organization connections
*InterconnectionsApi* | [**project_list_interconnections**](docs/InterconnectionsApi.md#project_list_interconnections) | **GET** /projects/{project_id}/connections | List project connections
*InterconnectionsApi* | [**update_interconnection**](docs/InterconnectionsApi.md#update_interconnection) | **PUT** /connections/{connection_id} | Update interconnection
*InterconnectionsApi* | [**update_virtual_circuit**](docs/InterconnectionsApi.md#update_virtual_circuit) | **PUT** /virtual-circuits/{id} | Update a virtual circuit
*InvitationsApi* | [**accept_invitation**](docs/InvitationsApi.md#accept_invitation) | **PUT** /invitations/{id} | Accept an invitation
*InvitationsApi* | [**decline_invitation**](docs/InvitationsApi.md#decline_invitation) | **DELETE** /invitations/{id} | Decline an invitation
*InvitationsApi* | [**find_invitation_by_id**](docs/InvitationsApi.md#find_invitation_by_id) | **GET** /invitations/{id} | View an invitation
*InvoicesApi* | [**find_organization_invoices**](docs/InvoicesApi.md#find_organization_invoices) | **GET** /organizations/{id}/invoices | Retrieve all invoices for an organization
*InvoicesApi* | [**get_invoice_by_id**](docs/InvoicesApi.md#get_invoice_by_id) | **GET** /invoices/{id} | Retrieve an invoice
*LicensesApi* | [**create_license**](docs/LicensesApi.md#create_license) | **POST** /projects/{id}/licenses | Create a License
*LicensesApi* | [**delete_license**](docs/LicensesApi.md#delete_license) | **DELETE** /licenses/{id} | Delete the license
*LicensesApi* | [**find_license_by_id**](docs/LicensesApi.md#find_license_by_id) | **GET** /licenses/{id} | Retrieve a license
*LicensesApi* | [**find_project_licenses**](docs/LicensesApi.md#find_project_licenses) | **GET** /projects/{id}/licenses | Retrieve all licenses
*LicensesApi* | [**update_license**](docs/LicensesApi.md#update_license) | **PUT** /licenses/{id} | Update the license
*MembershipsApi* | [**delete_membership**](docs/MembershipsApi.md#delete_membership) | **DELETE** /memberships/{id} | Delete the membership
*MembershipsApi* | [**find_membership_by_id**](docs/MembershipsApi.md#find_membership_by_id) | **GET** /memberships/{id} | Retrieve a membership
*MembershipsApi* | [**update_membership**](docs/MembershipsApi.md#update_membership) | **PUT** /memberships/{id} | Update the membership
*MetalGatewaysApi* | [**create_metal_gateway**](docs/MetalGatewaysApi.md#create_metal_gateway) | **POST** /projects/{project_id}/metal-gateways | Create a metal gateway
*MetalGatewaysApi* | [**create_metal_gateway_elastic_ip**](docs/MetalGatewaysApi.md#create_metal_gateway_elastic_ip) | **POST** /metal-gateways/{id}/ips | Create a Metal Gateway Elastic IP
*MetalGatewaysApi* | [**delete_metal_gateway**](docs/MetalGatewaysApi.md#delete_metal_gateway) | **DELETE** /metal-gateways/{id} | Deletes the metal gateway
*MetalGatewaysApi* | [**find_metal_gateway_by_id**](docs/MetalGatewaysApi.md#find_metal_gateway_by_id) | **GET** /metal-gateways/{id} | Returns the metal gateway
*MetalGatewaysApi* | [**find_metal_gateways_by_project**](docs/MetalGatewaysApi.md#find_metal_gateways_by_project) | **GET** /projects/{project_id}/metal-gateways | Returns all metal gateways for a project
*MetalGatewaysApi* | [**get_metal_gateway_elastic_ips**](docs/MetalGatewaysApi.md#get_metal_gateway_elastic_ips) | **GET** /metal-gateways/{id}/ips | List Metal Gateway Elastic IPs
*MetrosApi* | [**find_metros**](docs/MetrosApi.md#find_metros) | **GET** /locations/metros | Retrieve all metros
*MetrosApi* | [**get_metro**](docs/MetrosApi.md#get_metro) | **GET** /locations/metros/{id} | Retrieve a specific Metro&#39;s details
*OTPsApi* | [**find_ensure_otp**](docs/OTPsApi.md#find_ensure_otp) | **POST** /user/otp/verify/{otp} | Verify user by providing an OTP
*OTPsApi* | [**find_recovery_codes**](docs/OTPsApi.md#find_recovery_codes) | **GET** /user/otp/recovery-codes | Retrieve my recovery codes
*OTPsApi* | [**receive_codes**](docs/OTPsApi.md#receive_codes) | **POST** /user/otp/sms/receive | Receive an OTP per sms
*OTPsApi* | [**regenerate_codes**](docs/OTPsApi.md#regenerate_codes) | **POST** /user/otp/recovery-codes | Generate new recovery codes
*OperatingSystemsApi* | [**find_operating_system_version**](docs/OperatingSystemsApi.md#find_operating_system_version) | **GET** /operating-system-versions | Retrieve all operating system versions
*OperatingSystemsApi* | [**find_operating_systems**](docs/OperatingSystemsApi.md#find_operating_systems) | **GET** /operating-systems | Retrieve all operating systems
*OrganizationsApi* | [**create_organization**](docs/OrganizationsApi.md#create_organization) | **POST** /organizations | Create an organization
*OrganizationsApi* | [**create_organization_invitation**](docs/OrganizationsApi.md#create_organization_invitation) | **POST** /organizations/{id}/invitations | Create an invitation for an organization
*OrganizationsApi* | [**create_organization_project**](docs/OrganizationsApi.md#create_organization_project) | **POST** /organizations/{id}/projects | Create a project for the organization
*OrganizationsApi* | [**create_payment_method**](docs/OrganizationsApi.md#create_payment_method) | **POST** /organizations/{id}/payment-methods | Create a payment method for the given organization
*OrganizationsApi* | [**delete_organization**](docs/OrganizationsApi.md#delete_organization) | **DELETE** /organizations/{id} | Delete the organization
*OrganizationsApi* | [**find_operating_systems_by_organization**](docs/OrganizationsApi.md#find_operating_systems_by_organization) | **GET** /organizations/{id}/operating-systems | Retrieve all operating systems visible by the organization
*OrganizationsApi* | [**find_organization_by_id**](docs/OrganizationsApi.md#find_organization_by_id) | **GET** /organizations/{id} | Retrieve an organization&#39;s details
*OrganizationsApi* | [**find_organization_customdata**](docs/OrganizationsApi.md#find_organization_customdata) | **GET** /organizations/{id}/customdata | Retrieve the custom metadata of an organization
*OrganizationsApi* | [**find_organization_invitations**](docs/OrganizationsApi.md#find_organization_invitations) | **GET** /organizations/{id}/invitations | Retrieve organization invitations
*OrganizationsApi* | [**find_organization_payment_methods**](docs/OrganizationsApi.md#find_organization_payment_methods) | **GET** /organizations/{id}/payment-methods | Retrieve all payment methods of an organization
*OrganizationsApi* | [**find_organization_projects**](docs/OrganizationsApi.md#find_organization_projects) | **GET** /organizations/{id}/projects | Retrieve all projects of an organization
*OrganizationsApi* | [**find_organization_transfers**](docs/OrganizationsApi.md#find_organization_transfers) | **GET** /organizations/{id}/transfers | Retrieve all project transfer requests from or to an organization
*OrganizationsApi* | [**find_organizations**](docs/OrganizationsApi.md#find_organizations) | **GET** /organizations | Retrieve all organizations
*OrganizationsApi* | [**find_plans_by_organization**](docs/OrganizationsApi.md#find_plans_by_organization) | **GET** /organizations/{id}/plans | Retrieve all plans visible by the organization
*OrganizationsApi* | [**update_organization**](docs/OrganizationsApi.md#update_organization) | **PUT** /organizations/{id} | Update the organization
*PasswordResetTokensApi* | [**create_password_reset_token**](docs/PasswordResetTokensApi.md#create_password_reset_token) | **POST** /reset-password | Create a password reset token
*PasswordResetTokensApi* | [**reset_password**](docs/PasswordResetTokensApi.md#reset_password) | **DELETE** /reset-password | Reset current user password
*PaymentMethodsApi* | [**delete_payment_method**](docs/PaymentMethodsApi.md#delete_payment_method) | **DELETE** /payment-methods/{id} | Delete the payment method
*PaymentMethodsApi* | [**find_payment_method_by_id**](docs/PaymentMethodsApi.md#find_payment_method_by_id) | **GET** /payment-methods/{id} | Retrieve a payment method
*PaymentMethodsApi* | [**update_payment_method**](docs/PaymentMethodsApi.md#update_payment_method) | **PUT** /payment-methods/{id} | Update the payment method
*PlansApi* | [**find_plans**](docs/PlansApi.md#find_plans) | **GET** /plans | Retrieve all plans
*PlansApi* | [**find_plans_by_project**](docs/PlansApi.md#find_plans_by_project) | **GET** /projects/{id}/plans | Retrieve all plans visible by the project
*PortsApi* | [**assign_native_vlan**](docs/PortsApi.md#assign_native_vlan) | **POST** /ports/{id}/native-vlan | Assign a native VLAN
*PortsApi* | [**assign_port**](docs/PortsApi.md#assign_port) | **POST** /ports/{id}/assign | Assign a port to virtual network
*PortsApi* | [**bond_port**](docs/PortsApi.md#bond_port) | **POST** /ports/{id}/bond | Enabling bonding
*PortsApi* | [**convert_layer2**](docs/PortsApi.md#convert_layer2) | **POST** /ports/{id}/convert/layer-2 | Convert to Layer 2
*PortsApi* | [**convert_layer3**](docs/PortsApi.md#convert_layer3) | **POST** /ports/{id}/convert/layer-3 | Convert to Layer 3
*PortsApi* | [**create_port_vlan_assignment_batch**](docs/PortsApi.md#create_port_vlan_assignment_batch) | **POST** /ports/{id}/vlan-assignments/batches | Create a new Port-VLAN Assignment management batch
*PortsApi* | [**delete_native_vlan**](docs/PortsApi.md#delete_native_vlan) | **DELETE** /ports/{id}/native-vlan | Remove native VLAN
*PortsApi* | [**disbond_port**](docs/PortsApi.md#disbond_port) | **POST** /ports/{id}/disbond | Disabling bonding
*PortsApi* | [**find_port_by_id**](docs/PortsApi.md#find_port_by_id) | **GET** /ports/{id} | Retrieve a port
*PortsApi* | [**find_port_vlan_assignment_batch_by_port_id_and_batch_id**](docs/PortsApi.md#find_port_vlan_assignment_batch_by_port_id_and_batch_id) | **GET** /ports/{id}/vlan-assignments/batches/{batch_id} | Retrieve a VLAN Assignment Batch&#39;s details
*PortsApi* | [**find_port_vlan_assignment_batches**](docs/PortsApi.md#find_port_vlan_assignment_batches) | **GET** /ports/{id}/vlan-assignments/batches | List the VLAN Assignment Batches for a port
*PortsApi* | [**find_port_vlan_assignment_by_port_id_and_assignment_id**](docs/PortsApi.md#find_port_vlan_assignment_by_port_id_and_assignment_id) | **GET** /ports/{id}/vlan-assignments/{assignment_id} | Show a particular Port VLAN assignment&#39;s details
*PortsApi* | [**find_port_vlan_assignments**](docs/PortsApi.md#find_port_vlan_assignments) | **GET** /ports/{id}/vlan-assignments | List Current VLAN assignments for a port
*PortsApi* | [**unassign_port**](docs/PortsApi.md#unassign_port) | **POST** /ports/{id}/unassign | Unassign a port
*ProjectsApi* | [**create_project**](docs/ProjectsApi.md#create_project) | **POST** /projects | Create a project
*ProjectsApi* | [**create_project_invitation**](docs/ProjectsApi.md#create_project_invitation) | **POST** /projects/{project_id}/invitations | Create an invitation for a project
*ProjectsApi* | [**create_transfer_request**](docs/ProjectsApi.md#create_transfer_request) | **POST** /projects/{id}/transfers | Create a transfer request
*ProjectsApi* | [**delete_project**](docs/ProjectsApi.md#delete_project) | **DELETE** /projects/{id} | Delete the project
*ProjectsApi* | [**find_ip_reservation_customdata**](docs/ProjectsApi.md#find_ip_reservation_customdata) | **GET** /projects/{project_id}/ips/{id}/customdata | Retrieve the custom metadata of an IP Reservation
*ProjectsApi* | [**find_project_by_id**](docs/ProjectsApi.md#find_project_by_id) | **GET** /projects/{id} | Retrieve a project
*ProjectsApi* | [**find_project_customdata**](docs/ProjectsApi.md#find_project_customdata) | **GET** /projects/{id}/customdata | Retrieve the custom metadata of a project
*ProjectsApi* | [**find_project_invitations**](docs/ProjectsApi.md#find_project_invitations) | **GET** /projects/{project_id}/invitations | Retrieve project invitations
*ProjectsApi* | [**find_project_memberships**](docs/ProjectsApi.md#find_project_memberships) | **GET** /projects/{project_id}/memberships | Retrieve project memberships
*ProjectsApi* | [**find_projects**](docs/ProjectsApi.md#find_projects) | **GET** /projects | Retrieve all projects
*ProjectsApi* | [**update_project**](docs/ProjectsApi.md#update_project) | **PUT** /projects/{id} | Update the project
*SSHKeysApi* | [**create_project_ssh_key**](docs/SSHKeysApi.md#create_project_ssh_key) | **POST** /projects/{id}/ssh-keys | Create a ssh key for the given project
*SSHKeysApi* | [**create_ssh_key**](docs/SSHKeysApi.md#create_ssh_key) | **POST** /ssh-keys | Create a ssh key for the current user
*SSHKeysApi* | [**delete_ssh_key**](docs/SSHKeysApi.md#delete_ssh_key) | **DELETE** /ssh-keys/{id} | Delete the ssh key
*SSHKeysApi* | [**find_device_ssh_keys**](docs/SSHKeysApi.md#find_device_ssh_keys) | **GET** /devices/{id}/ssh-keys | Retrieve a device&#39;s ssh keys
*SSHKeysApi* | [**find_project_ssh_keys**](docs/SSHKeysApi.md#find_project_ssh_keys) | **GET** /projects/{id}/ssh-keys | Retrieve a project&#39;s ssh keys
*SSHKeysApi* | [**find_ssh_key_by_id**](docs/SSHKeysApi.md#find_ssh_key_by_id) | **GET** /ssh-keys/{id} | Retrieve a ssh key
*SSHKeysApi* | [**find_ssh_keys**](docs/SSHKeysApi.md#find_ssh_keys) | **GET** /ssh-keys | Retrieve all ssh keys
*SSHKeysApi* | [**update_ssh_key**](docs/SSHKeysApi.md#update_ssh_key) | **PUT** /ssh-keys/{id} | Update the ssh key
*SelfServiceReservationsApi* | [**create_self_service_reservation**](docs/SelfServiceReservationsApi.md#create_self_service_reservation) | **POST** /projects/{project_id}/self-service/reservations | Create a reservation
*SelfServiceReservationsApi* | [**find_self_service_reservation**](docs/SelfServiceReservationsApi.md#find_self_service_reservation) | **GET** /projects/{project_id}/self-service/reservations/{id} | Retrieve a reservation
*SelfServiceReservationsApi* | [**find_self_service_reservations**](docs/SelfServiceReservationsApi.md#find_self_service_reservations) | **GET** /projects/{project_id}/self-service/reservations | Retrieve all reservations
*SpotMarketApi* | [**create_spot_market_request**](docs/SpotMarketApi.md#create_spot_market_request) | **POST** /projects/{id}/spot-market-requests | Create a spot market request
*SpotMarketApi* | [**delete_spot_market_request**](docs/SpotMarketApi.md#delete_spot_market_request) | **DELETE** /spot-market-requests/{id} | Delete the spot market request
*SpotMarketApi* | [**find_metro_spot_market_prices**](docs/SpotMarketApi.md#find_metro_spot_market_prices) | **GET** /market/spot/prices/metros | Get current spot market prices for metros
*SpotMarketApi* | [**find_spot_market_prices**](docs/SpotMarketApi.md#find_spot_market_prices) | **GET** /market/spot/prices | Get current spot market prices
*SpotMarketApi* | [**find_spot_market_prices_history**](docs/SpotMarketApi.md#find_spot_market_prices_history) | **GET** /market/spot/prices/history | Get spot market prices for a given period of time
*SpotMarketApi* | [**find_spot_market_request_by_id**](docs/SpotMarketApi.md#find_spot_market_request_by_id) | **GET** /spot-market-requests/{id} | Retrieve a spot market request
*SpotMarketApi* | [**list_spot_market_requests**](docs/SpotMarketApi.md#list_spot_market_requests) | **GET** /projects/{id}/spot-market-requests | List spot market requests
*SupportRequestApi* | [**request_suppert**](docs/SupportRequestApi.md#request_suppert) | **POST** /support-requests | Create a support ticket
*TransferRequestsApi* | [**accept_transfer_request**](docs/TransferRequestsApi.md#accept_transfer_request) | **PUT** /transfers/{id} | Accept a transfer request
*TransferRequestsApi* | [**decline_transfer_request**](docs/TransferRequestsApi.md#decline_transfer_request) | **DELETE** /transfers/{id} | Decline a transfer request
*TransferRequestsApi* | [**find_transfer_request_by_id**](docs/TransferRequestsApi.md#find_transfer_request_by_id) | **GET** /transfers/{id} | View a transfer request
*TwoFactorAuthApi* | [**disable_tfa_app**](docs/TwoFactorAuthApi.md#disable_tfa_app) | **DELETE** /user/otp/app | Disable two factor authentication
*TwoFactorAuthApi* | [**disable_tfa_sms**](docs/TwoFactorAuthApi.md#disable_tfa_sms) | **DELETE** /user/otp/sms | Disable two factor authentication
*TwoFactorAuthApi* | [**enable_tfa_app**](docs/TwoFactorAuthApi.md#enable_tfa_app) | **POST** /user/otp/app | Enable two factor auth using app
*TwoFactorAuthApi* | [**enable_tfa_sms**](docs/TwoFactorAuthApi.md#enable_tfa_sms) | **POST** /user/otp/sms | Enable two factor auth using sms
*UsagesApi* | [**find_device_usages**](docs/UsagesApi.md#find_device_usages) | **GET** /devices/{id}/usages | Retrieve all usages for device
*UsagesApi* | [**find_project_usage**](docs/UsagesApi.md#find_project_usage) | **GET** /projects/{id}/usages | Retrieve all usages for project
*UserVerificationTokensApi* | [**consume_verification_request**](docs/UserVerificationTokensApi.md#consume_verification_request) | **PUT** /verify-email | Verify a user using an email verification token
*UserVerificationTokensApi* | [**create_validation_request**](docs/UserVerificationTokensApi.md#create_validation_request) | **POST** /verify-email | Create an email verification request
*UserdataApi* | [**validate_userdata**](docs/UserdataApi.md#validate_userdata) | **POST** /userdata/validate | Validate user data
*UsersApi* | [**create_user**](docs/UsersApi.md#create_user) | **POST** /users | Create a user
*UsersApi* | [**find_current_user**](docs/UsersApi.md#find_current_user) | **GET** /user | Retrieve the current user
*UsersApi* | [**find_invitations**](docs/UsersApi.md#find_invitations) | **GET** /invitations | Retrieve current user invitations
*UsersApi* | [**find_user_by_id**](docs/UsersApi.md#find_user_by_id) | **GET** /users/{id} | Retrieve a user
*UsersApi* | [**find_user_customdata**](docs/UsersApi.md#find_user_customdata) | **GET** /users/{id}/customdata | Retrieve the custom metadata of a user
*UsersApi* | [**find_users**](docs/UsersApi.md#find_users) | **GET** /users | Retrieve all users
*UsersApi* | [**update_current_user**](docs/UsersApi.md#update_current_user) | **PUT** /user | Update the current user
*VLANsApi* | [**create_virtual_network**](docs/VLANsApi.md#create_virtual_network) | **POST** /projects/{id}/virtual-networks | Create a virtual network
*VLANsApi* | [**delete_virtual_network**](docs/VLANsApi.md#delete_virtual_network) | **DELETE** /virtual-networks/{id} | Delete a virtual network
*VLANsApi* | [**find_virtual_networks**](docs/VLANsApi.md#find_virtual_networks) | **GET** /projects/{id}/virtual-networks | Retrieve all virtual networks
*VLANsApi* | [**get_virtual_network**](docs/VLANsApi.md#get_virtual_network) | **GET** /virtual-networks/{id} | Get a virtual network
*VRFsApi* | [**bgp_dynamic_neighbors_id_get**](docs/VRFsApi.md#bgp_dynamic_neighbors_id_get) | **GET** /bgp-dynamic-neighbors/{id} | Retrieve a BGP Dynamic Neighbor
*VRFsApi* | [**create_bgp_dynamic_neighbor**](docs/VRFsApi.md#create_bgp_dynamic_neighbor) | **POST** /metal-gateways/{id}/bgp-dynamic-neighbors | Create a VRF BGP Dynamic Neighbor range
*VRFsApi* | [**create_vrf**](docs/VRFsApi.md#create_vrf) | **POST** /projects/{id}/vrfs | Create a new VRF in the specified project
*VRFsApi* | [**create_vrf_route**](docs/VRFsApi.md#create_vrf_route) | **POST** /vrfs/{id}/routes | Create a VRF route
*VRFsApi* | [**delete_bgp_dynamic_neighbor_by_id**](docs/VRFsApi.md#delete_bgp_dynamic_neighbor_by_id) | **DELETE** /bgp-dynamic-neighbors/{id} | Delete a VRF BGP Dynamic Neighbor
*VRFsApi* | [**delete_vrf**](docs/VRFsApi.md#delete_vrf) | **DELETE** /vrfs/{id} | Delete the VRF
*VRFsApi* | [**delete_vrf_route_by_id**](docs/VRFsApi.md#delete_vrf_route_by_id) | **DELETE** /routes/{id} | Delete a VRF Route
*VRFsApi* | [**find_vrf_by_id**](docs/VRFsApi.md#find_vrf_by_id) | **GET** /vrfs/{id} | Retrieve a VRF
*VRFsApi* | [**find_vrf_ip_reservation**](docs/VRFsApi.md#find_vrf_ip_reservation) | **GET** /vrfs/{vrf_id}/ips/{id} | Retrieve all VRF IP Reservations in the VRF
*VRFsApi* | [**find_vrf_ip_reservations**](docs/VRFsApi.md#find_vrf_ip_reservations) | **GET** /vrfs/{id}/ips | Retrieve all VRF IP Reservations in the VRF
*VRFsApi* | [**find_vrf_route_by_id**](docs/VRFsApi.md#find_vrf_route_by_id) | **GET** /routes/{id} | Retrieve a VRF Route
*VRFsApi* | [**find_vrfs**](docs/VRFsApi.md#find_vrfs) | **GET** /projects/{id}/vrfs | Retrieve all VRFs in the project
*VRFsApi* | [**get_bgp_dynamic_neighbors**](docs/VRFsApi.md#get_bgp_dynamic_neighbors) | **GET** /metal-gateways/{id}/bgp-dynamic-neighbors | List BGP Dynamic Neighbors
*VRFsApi* | [**get_vrf_routes**](docs/VRFsApi.md#get_vrf_routes) | **GET** /vrfs/{id}/routes | Retrieve all routes in the VRF
*VRFsApi* | [**update_vrf**](docs/VRFsApi.md#update_vrf) | **PUT** /vrfs/{id} | Update the VRF
*VRFsApi* | [**update_vrf_route_by_id**](docs/VRFsApi.md#update_vrf_route_by_id) | **PUT** /routes/{id} | Update a VRF Route


## Documentation For Models

 - [ActivateHardwareReservationRequest](docs/ActivateHardwareReservationRequest.md)
 - [Address](docs/Address.md)
 - [Attribute](docs/Attribute.md)
 - [AttributeData](docs/AttributeData.md)
 - [AuthToken](docs/AuthToken.md)
 - [AuthTokenInput](docs/AuthTokenInput.md)
 - [AuthTokenList](docs/AuthTokenList.md)
 - [AuthTokenProject](docs/AuthTokenProject.md)
 - [AuthTokenUser](docs/AuthTokenUser.md)
 - [BGPSessionInput](docs/BGPSessionInput.md)
 - [Batch](docs/Batch.md)
 - [BatchesList](docs/BatchesList.md)
 - [BgpConfig](docs/BgpConfig.md)
 - [BgpConfigRequestInput](docs/BgpConfigRequestInput.md)
 - [BgpDynamicNeighbor](docs/BgpDynamicNeighbor.md)
 - [BgpDynamicNeighborCreateInput](docs/BgpDynamicNeighborCreateInput.md)
 - [BgpDynamicNeighborList](docs/BgpDynamicNeighborList.md)
 - [BgpNeighborData](docs/BgpNeighborData.md)
 - [BgpRoute](docs/BgpRoute.md)
 - [BgpSession](docs/BgpSession.md)
 - [BgpSessionList](docs/BgpSessionList.md)
 - [BgpSessionNeighbors](docs/BgpSessionNeighbors.md)
 - [BondPortData](docs/BondPortData.md)
 - [CapacityCheckPerFacilityInfo](docs/CapacityCheckPerFacilityInfo.md)
 - [CapacityCheckPerFacilityList](docs/CapacityCheckPerFacilityList.md)
 - [CapacityCheckPerMetroInfo](docs/CapacityCheckPerMetroInfo.md)
 - [CapacityCheckPerMetroList](docs/CapacityCheckPerMetroList.md)
 - [CapacityInput](docs/CapacityInput.md)
 - [CapacityLevelPerBaremetal](docs/CapacityLevelPerBaremetal.md)
 - [CapacityList](docs/CapacityList.md)
 - [Component](docs/Component.md)
 - [Coordinates](docs/Coordinates.md)
 - [CreateDeviceRequest](docs/CreateDeviceRequest.md)
 - [CreateEmailInput](docs/CreateEmailInput.md)
 - [CreateMetalGatewayRequest](docs/CreateMetalGatewayRequest.md)
 - [CreateOrganizationInterconnectionRequest](docs/CreateOrganizationInterconnectionRequest.md)
 - [CreateSelfServiceReservationRequest](docs/CreateSelfServiceReservationRequest.md)
 - [CreateSelfServiceReservationRequestPeriod](docs/CreateSelfServiceReservationRequestPeriod.md)
 - [DedicatedPortCreateInput](docs/DedicatedPortCreateInput.md)
 - [Device](docs/Device.md)
 - [DeviceActionInput](docs/DeviceActionInput.md)
 - [DeviceActionsInner](docs/DeviceActionsInner.md)
 - [DeviceCreateInFacilityInput](docs/DeviceCreateInFacilityInput.md)
 - [DeviceCreateInMetroInput](docs/DeviceCreateInMetroInput.md)
 - [DeviceCreateInput](docs/DeviceCreateInput.md)
 - [DeviceCreatedBy](docs/DeviceCreatedBy.md)
 - [DeviceHealthRollup](docs/DeviceHealthRollup.md)
 - [DeviceList](docs/DeviceList.md)
 - [DeviceMetro](docs/DeviceMetro.md)
 - [DeviceProject](docs/DeviceProject.md)
 - [DeviceProjectLite](docs/DeviceProjectLite.md)
 - [DeviceUpdateInput](docs/DeviceUpdateInput.md)
 - [DeviceUsage](docs/DeviceUsage.md)
 - [DeviceUsageList](docs/DeviceUsageList.md)
 - [Disk](docs/Disk.md)
 - [Email](docs/Email.md)
 - [EmailInput](docs/EmailInput.md)
 - [Entitlement](docs/Entitlement.md)
 - [Error](docs/Error.md)
 - [Event](docs/Event.md)
 - [EventList](docs/EventList.md)
 - [FabricServiceToken](docs/FabricServiceToken.md)
 - [Facility](docs/Facility.md)
 - [FacilityInput](docs/FacilityInput.md)
 - [FacilityInputFacility](docs/FacilityInputFacility.md)
 - [FacilityList](docs/FacilityList.md)
 - [Filesystem](docs/Filesystem.md)
 - [FindIPAddressById200Response](docs/FindIPAddressById200Response.md)
 - [FindMetalGatewayById200Response](docs/FindMetalGatewayById200Response.md)
 - [FindTrafficTimeframeParameter](docs/FindTrafficTimeframeParameter.md)
 - [FirmwareSet](docs/FirmwareSet.md)
 - [FirmwareSetListResponse](docs/FirmwareSetListResponse.md)
 - [FirmwareSetResponse](docs/FirmwareSetResponse.md)
 - [GlobalBgpRange](docs/GlobalBgpRange.md)
 - [GlobalBgpRangeList](docs/GlobalBgpRangeList.md)
 - [HardwareReservation](docs/HardwareReservation.md)
 - [HardwareReservationList](docs/HardwareReservationList.md)
 - [Href](docs/Href.md)
 - [IPAddress](docs/IPAddress.md)
 - [IPAssignment](docs/IPAssignment.md)
 - [IPAssignmentInput](docs/IPAssignmentInput.md)
 - [IPAssignmentList](docs/IPAssignmentList.md)
 - [IPAssignmentMetro](docs/IPAssignmentMetro.md)
 - [IPAssignmentUpdateInput](docs/IPAssignmentUpdateInput.md)
 - [IPAvailabilitiesList](docs/IPAvailabilitiesList.md)
 - [IPReservation](docs/IPReservation.md)
 - [IPReservationFacility](docs/IPReservationFacility.md)
 - [IPReservationList](docs/IPReservationList.md)
 - [IPReservationListIpAddressesInner](docs/IPReservationListIpAddressesInner.md)
 - [IPReservationMetro](docs/IPReservationMetro.md)
 - [IPReservationRequestInput](docs/IPReservationRequestInput.md)
 - [InstancesBatchCreateInput](docs/InstancesBatchCreateInput.md)
 - [InstancesBatchCreateInputBatchesInner](docs/InstancesBatchCreateInputBatchesInner.md)
 - [Interconnection](docs/Interconnection.md)
 - [InterconnectionList](docs/InterconnectionList.md)
 - [InterconnectionPort](docs/InterconnectionPort.md)
 - [InterconnectionPortList](docs/InterconnectionPortList.md)
 - [InterconnectionUpdateInput](docs/InterconnectionUpdateInput.md)
 - [Invitation](docs/Invitation.md)
 - [InvitationInput](docs/InvitationInput.md)
 - [InvitationList](docs/InvitationList.md)
 - [Invoice](docs/Invoice.md)
 - [InvoiceList](docs/InvoiceList.md)
 - [License](docs/License.md)
 - [LicenseCreateInput](docs/LicenseCreateInput.md)
 - [LicenseList](docs/LicenseList.md)
 - [LicenseUpdateInput](docs/LicenseUpdateInput.md)
 - [LineItem](docs/LineItem.md)
 - [Membership](docs/Membership.md)
 - [MembershipInput](docs/MembershipInput.md)
 - [MembershipList](docs/MembershipList.md)
 - [Meta](docs/Meta.md)
 - [Metadata](docs/Metadata.md)
 - [MetadataNetwork](docs/MetadataNetwork.md)
 - [MetadataNetworkNetwork](docs/MetadataNetworkNetwork.md)
 - [MetadataNetworkNetworkBonding](docs/MetadataNetworkNetworkBonding.md)
 - [MetalGateway](docs/MetalGateway.md)
 - [MetalGatewayCreateInput](docs/MetalGatewayCreateInput.md)
 - [MetalGatewayElasticIpCreateInput](docs/MetalGatewayElasticIpCreateInput.md)
 - [MetalGatewayList](docs/MetalGatewayList.md)
 - [MetalGatewayListMetalGatewaysInner](docs/MetalGatewayListMetalGatewaysInner.md)
 - [MetalGatewayLite](docs/MetalGatewayLite.md)
 - [Metro](docs/Metro.md)
 - [MetroInput](docs/MetroInput.md)
 - [MetroList](docs/MetroList.md)
 - [Mount](docs/Mount.md)
 - [MoveHardwareReservationRequest](docs/MoveHardwareReservationRequest.md)
 - [NewPassword](docs/NewPassword.md)
 - [OperatingSystem](docs/OperatingSystem.md)
 - [OperatingSystemList](docs/OperatingSystemList.md)
 - [Organization](docs/Organization.md)
 - [OrganizationInput](docs/OrganizationInput.md)
 - [OrganizationList](docs/OrganizationList.md)
 - [ParentBlock](docs/ParentBlock.md)
 - [Partition](docs/Partition.md)
 - [PaymentMethod](docs/PaymentMethod.md)
 - [PaymentMethodBillingAddress](docs/PaymentMethodBillingAddress.md)
 - [PaymentMethodCreateInput](docs/PaymentMethodCreateInput.md)
 - [PaymentMethodList](docs/PaymentMethodList.md)
 - [PaymentMethodUpdateInput](docs/PaymentMethodUpdateInput.md)
 - [Plan](docs/Plan.md)
 - [PlanAvailableInInner](docs/PlanAvailableInInner.md)
 - [PlanAvailableInInnerPrice](docs/PlanAvailableInInnerPrice.md)
 - [PlanAvailableInMetrosInner](docs/PlanAvailableInMetrosInner.md)
 - [PlanList](docs/PlanList.md)
 - [PlanSpecs](docs/PlanSpecs.md)
 - [PlanSpecsCpusInner](docs/PlanSpecsCpusInner.md)
 - [PlanSpecsDrivesInner](docs/PlanSpecsDrivesInner.md)
 - [PlanSpecsFeatures](docs/PlanSpecsFeatures.md)
 - [PlanSpecsMemory](docs/PlanSpecsMemory.md)
 - [PlanSpecsNicsInner](docs/PlanSpecsNicsInner.md)
 - [Port](docs/Port.md)
 - [PortAssignInput](docs/PortAssignInput.md)
 - [PortConvertLayer3Input](docs/PortConvertLayer3Input.md)
 - [PortConvertLayer3InputRequestIpsInner](docs/PortConvertLayer3InputRequestIpsInner.md)
 - [PortData](docs/PortData.md)
 - [PortVlanAssignment](docs/PortVlanAssignment.md)
 - [PortVlanAssignmentBatch](docs/PortVlanAssignmentBatch.md)
 - [PortVlanAssignmentBatchCreateInput](docs/PortVlanAssignmentBatchCreateInput.md)
 - [PortVlanAssignmentBatchCreateInputVlanAssignmentsInner](docs/PortVlanAssignmentBatchCreateInputVlanAssignmentsInner.md)
 - [PortVlanAssignmentBatchList](docs/PortVlanAssignmentBatchList.md)
 - [PortVlanAssignmentBatchVlanAssignmentsInner](docs/PortVlanAssignmentBatchVlanAssignmentsInner.md)
 - [PortVlanAssignmentList](docs/PortVlanAssignmentList.md)
 - [Project](docs/Project.md)
 - [ProjectCreateFromRootInput](docs/ProjectCreateFromRootInput.md)
 - [ProjectCreateInput](docs/ProjectCreateInput.md)
 - [ProjectIdName](docs/ProjectIdName.md)
 - [ProjectList](docs/ProjectList.md)
 - [ProjectUpdateInput](docs/ProjectUpdateInput.md)
 - [ProjectUsage](docs/ProjectUsage.md)
 - [ProjectUsageList](docs/ProjectUsageList.md)
 - [Raid](docs/Raid.md)
 - [RecoveryCodeList](docs/RecoveryCodeList.md)
 - [RequestIPReservation201Response](docs/RequestIPReservation201Response.md)
 - [RequestIPReservationRequest](docs/RequestIPReservationRequest.md)
 - [SSHKey](docs/SSHKey.md)
 - [SSHKeyCreateInput](docs/SSHKeyCreateInput.md)
 - [SSHKeyInput](docs/SSHKeyInput.md)
 - [SSHKeyList](docs/SSHKeyList.md)
 - [SelfServiceReservationItemRequest](docs/SelfServiceReservationItemRequest.md)
 - [SelfServiceReservationItemResponse](docs/SelfServiceReservationItemResponse.md)
 - [SelfServiceReservationList](docs/SelfServiceReservationList.md)
 - [SelfServiceReservationResponse](docs/SelfServiceReservationResponse.md)
 - [ServerInfo](docs/ServerInfo.md)
 - [SpotMarketPricesList](docs/SpotMarketPricesList.md)
 - [SpotMarketPricesPerMetroList](docs/SpotMarketPricesPerMetroList.md)
 - [SpotMarketPricesPerMetroReport](docs/SpotMarketPricesPerMetroReport.md)
 - [SpotMarketRequest](docs/SpotMarketRequest.md)
 - [SpotMarketRequestCreateInput](docs/SpotMarketRequestCreateInput.md)
 - [SpotMarketRequestCreateInputInstanceParameters](docs/SpotMarketRequestCreateInputInstanceParameters.md)
 - [SpotMarketRequestList](docs/SpotMarketRequestList.md)
 - [SpotMarketRequestMetro](docs/SpotMarketRequestMetro.md)
 - [SpotPricesDatapoints](docs/SpotPricesDatapoints.md)
 - [SpotPricesHistoryReport](docs/SpotPricesHistoryReport.md)
 - [SpotPricesPerBaremetal](docs/SpotPricesPerBaremetal.md)
 - [SpotPricesPerFacility](docs/SpotPricesPerFacility.md)
 - [SpotPricesPerNewFacility](docs/SpotPricesPerNewFacility.md)
 - [SpotPricesReport](docs/SpotPricesReport.md)
 - [Storage](docs/Storage.md)
 - [SupportRequestInput](docs/SupportRequestInput.md)
 - [TransferRequest](docs/TransferRequest.md)
 - [TransferRequestInput](docs/TransferRequestInput.md)
 - [TransferRequestList](docs/TransferRequestList.md)
 - [UpdateEmailInput](docs/UpdateEmailInput.md)
 - [User](docs/User.md)
 - [UserCreateInput](docs/UserCreateInput.md)
 - [UserLimited](docs/UserLimited.md)
 - [UserList](docs/UserList.md)
 - [UserLite](docs/UserLite.md)
 - [UserUpdateInput](docs/UserUpdateInput.md)
 - [Userdata](docs/Userdata.md)
 - [VerifyEmail](docs/VerifyEmail.md)
 - [VirtualCircuit](docs/VirtualCircuit.md)
 - [VirtualCircuitCreateInput](docs/VirtualCircuitCreateInput.md)
 - [VirtualCircuitList](docs/VirtualCircuitList.md)
 - [VirtualCircuitUpdateInput](docs/VirtualCircuitUpdateInput.md)
 - [VirtualNetwork](docs/VirtualNetwork.md)
 - [VirtualNetworkCreateInput](docs/VirtualNetworkCreateInput.md)
 - [VirtualNetworkList](docs/VirtualNetworkList.md)
 - [VlanFabricVcCreateInput](docs/VlanFabricVcCreateInput.md)
 - [VlanVirtualCircuit](docs/VlanVirtualCircuit.md)
 - [VlanVirtualCircuitCreateInput](docs/VlanVirtualCircuitCreateInput.md)
 - [VlanVirtualCircuitUpdateInput](docs/VlanVirtualCircuitUpdateInput.md)
 - [Vrf](docs/Vrf.md)
 - [VrfCreateInput](docs/VrfCreateInput.md)
 - [VrfFabricVcCreateInput](docs/VrfFabricVcCreateInput.md)
 - [VrfIpReservation](docs/VrfIpReservation.md)
 - [VrfIpReservationCreateInput](docs/VrfIpReservationCreateInput.md)
 - [VrfIpReservationList](docs/VrfIpReservationList.md)
 - [VrfList](docs/VrfList.md)
 - [VrfMetalGateway](docs/VrfMetalGateway.md)
 - [VrfMetalGatewayCreateInput](docs/VrfMetalGatewayCreateInput.md)
 - [VrfRoute](docs/VrfRoute.md)
 - [VrfRouteCreateInput](docs/VrfRouteCreateInput.md)
 - [VrfRouteList](docs/VrfRouteList.md)
 - [VrfRouteUpdateInput](docs/VrfRouteUpdateInput.md)
 - [VrfUpdateInput](docs/VrfUpdateInput.md)
 - [VrfVirtualCircuit](docs/VrfVirtualCircuit.md)
 - [VrfVirtualCircuitCreateInput](docs/VrfVirtualCircuitCreateInput.md)
 - [VrfVirtualCircuitUpdateInput](docs/VrfVirtualCircuitUpdateInput.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="x_auth_token"></a>
### x_auth_token

- **Type**: API key
- **API key parameter name**: X-Auth-Token
- **Location**: HTTP header


## Author

support@equinixmetal.com


